Example templates for ``wagtail_integration`` app.

Both pages extend from "page/base.html", which does not exist, unless
you make it.

**fobi_form_page.html**

Rendering the form page.

**fobi_form_page_success.html**

Rendering the success page.
